@@ -1,6 +1,6 @@
 package Net::Appliance::Session::APIv2;
 {
-  $Net::Appliance::Session::APIv2::VERSION = '3.113610';
+  $Net::Appliance::Session::APIv2::VERSION = '3.121570';
 }
 
 use Moose;
@@ -250,6 +250,20 @@ foreach my $name (qw/
 
 1;
 
+# ABSTRACT: Back-compatibility with API version 2
+
+
+__END__
+=pod
+
+=head1 NAME
+
+Net::Appliance::Session::APIv2 - Back-compatibility with API version 2
+
+=head1 VERSION
+
+version 3.121570
+
 =head1 INTRODUCTION
 
 Version 3 of Net::Appliance::Session is a complete rewrite of the previous
@@ -313,7 +327,7 @@ messages.
 
 When automating a CLI, this doesn't really make much sense. If a human makes a
 mistake, the CLI shows an error. A computer-driven script should I<never> make
-a mistake - it will have been tested and developed. It's unecessary overhead
+a mistake - it will have been tested and developed. It's unnecessary overhead
 to check for errors all the time and attempt to recover. Of course, the remote
 device might still have a problem and report it, or die, but in that case
 version 3 of the module will still itself C<die> with an error message.
@@ -410,4 +424,16 @@ See the extensive documentation of L<Net::Appliance::Session> or the
 underlying L<Net::CLI::Interact> module for details. You have I<a lot> more on
 offer with the version 3 API.
 
+=head1 AUTHOR
+
+Oliver Gorwits <oliver@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Oliver Gorwits.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
